summaryrefslogtreecommitdiff
path: root/keyboards
diff options
context:
space:
mode:
authorXScorpion2 <rcalt2vt@gmail.com>2019-05-06 17:29:13 -0500
committerDrashna Jaelre <drashna@live.com>2019-05-06 15:29:13 -0700
commite83e3165559eba17a965541726b5c09112bab9d5 (patch)
treebe21ced860b8056edf5dd57a990571928a4cb717 /keyboards
parente01b2d518a1a08ce07278ef9a38c7a793c843749 (diff)
[Keyboard] Enable RGBLIGHT_ANIMATIONS by default on the Zen rev2 (#5805)
* Enable RGBLIGHT_ANIMATIONS by default on the Zen rev2 * Also fixing OLED as it is upside down
Diffstat (limited to 'keyboards')
-rw-r--r--keyboards/zen/rev2/config.h1
-rw-r--r--keyboards/zen/rev2/rev2.c4
2 files changed, 3 insertions, 2 deletions
diff --git a/keyboards/zen/rev2/config.h b/keyboards/zen/rev2/config.h
index 5fa2627602..c56956108d 100644
--- a/keyboards/zen/rev2/config.h
+++ b/keyboards/zen/rev2/config.h
@@ -65,6 +65,7 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
/* ws2812 RGB LED */
#define RGBLED_NUM 34 // Number of LEDs
+#define RGBLIGHT_ANIMATIONS
/*
* Feature disable options
diff --git a/keyboards/zen/rev2/rev2.c b/keyboards/zen/rev2/rev2.c
index 3f4a92c63d..28a5a9f203 100644
--- a/keyboards/zen/rev2/rev2.c
+++ b/keyboards/zen/rev2/rev2.c
@@ -24,7 +24,7 @@ const char* layer_name_user(uint32_t layer) {
__attribute__((weak))
void render_status(void) {
// Setup for 90 degree rendering because it's awesome!
// It can house 16 lines of text, with 5 letters each line
// Render to mode icon
static const char PROGMEM mode_logo[2][4] = {
@@ -49,7 +49,7 @@ void render_status(void) {
oled_rotation_t oled_init_user(oled_rotation_t rotation) {
if (is_keyboard_master())
- return OLED_ROTATION_90; // flips the display 90 degrees if mainhand
+ return OLED_ROTATION_270; // flips the display 270 degrees if mainhand
return rotation;
}
@@ -24,7 +24,7 @@ const char* layer_name_user(uint32_t layer) {
__attribute__((weak))
void render_status(void) {
- // Setup for 90 degree rendering because it's awesome!
+ // Setup for 270 degree rendering because it's awesome!
// It can house 16 lines of text, with 5 letters each line
// Render to mode icon